import requests
from osrs_net.item import Item


class GrandExchange:

    @staticmethod
    def item(id_num):
        url = 'https://rsbuddy.com/exchange/graphs/1440/{}.json'.format(id_num)
        data = requests.get(url).json()
        current_item = data[len(data) - 1]
        price_data = {
            'price': current_item['overallPrice'],
            'buyPrice': current_item['buyingPrice'],
            'sellPrice': current_item['sellingPrice']
        }

        result = Item(id_num, Item.id_to_name(id_num), price_data)
        return result



import requests
import json
import os
import osrs_net

from osrs_net.util.file_io import write, create_directory


API_URL = 'https://storage.googleapis.com/osbuddy-exchange/summary.json'


def get_item_data():
    response = requests.get(API_URL)
    return response.json()


def create_item_database(item_data):
    database = dict()
    for key in list(item_data):
        name = item_data[key]['name']
        item_id = item_data[key]['id']
        members = item_data[key]['members']
        item_dict = {'name': name, 'id': item_id, 'members': members}
        database[name.lower()] = item_dict

    return database


if __name__ == '__main__':
    import argparse

    parser = argparse.ArgumentParser()
    default_path = os.path.join(os.path.dirname(osrs_net.__file__), 'resources', 'items.json')
    parser.add_argument('-o', '--output_file', default=default_path, help='Path to output file')
    args = parser.parse_args()

    out_file = args.output_file

    data = get_item_data()
    database = create_item_database(data)

    create_directory(out_file)
    write(json.dumps(database, indent=4), out_file)







import json
import os

from osrs_net.util.file_io import read, get_base_dir


class Item:
    def __init__(self, item_id, item_name, price_data):
        self.id = item_id
        self.name = item_name
        self.price_data = price_data

    @staticmethod
    def _get_item_data():
        base_dir = get_base_dir()
        filepath = os.path.join(base_dir, 'resources', 'items.json')
        text = read(filepath)
        return json.loads(text)

    @staticmethod
    def item_id(name):
        item_data = Item._get_item_data()
        try:
            return item_data[name.lower()]['id']
        except KeyError:
            return None

    @staticmethod
    def search_items(search_term):
        item_data = Item._get_item_data()
        matches = []
        for item in item_data:
            if search_term in item:
                matches.append(item_data[item]['id'])
        return matches

    @staticmethod
    def id_to_name(id_num):
        data = Item._get_item_data()
        for item in data:
            if data[item]['id'] == id_num:
                return data[item]['name']
        return None



import os
import sys
import osrs_net


def write(string, filepath):
    try:
        with open(filepath, 'w') as f:
            f.write(string)
        return True

    except Exception as e:
        print('Failed to write data to file: {}, error: {}'.format(filepath, e))


def read(filepath):
    try:
        with open(filepath, 'r') as f:
            return f.read()
    except Exception as e:
        print('Failed to read from file: {}, error: {}'.format(filepath, e))


def create_directory(directory_path):
    try:
        os.makedirs(os.path.dirname(directory_path), exist_ok=True)
    except Exception as e:
        print('Failed to create directory: {}, error: {}'.format(directory_path, e))


def get_base_dir():
    try:
        base_dir = sys._MEIPASS
    except AttributeError:
        base_dir = os.path.dirname(osrs_net.__file__)

    return base_dir



import setuptools

setuptools.setup(
    name='osrs_net',
    version='0.0.4',
    author='Patrick Seute',
    author_email='patrick.seute@gmail.com',
    description='Simple OSBuddy Exchange API Wrapper',
    packages=setuptools.find_packages(),
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent'
    ],
    install_requires=[
        'requests'
    ]
)
